@@ -1,4 +1,4 @@
-"clock2cart" <-
+`clock2cart` <-
 function(rho, phi = NULL, circle)
   ## Author: Rene Locher
   ## Version: 2005-10-05
@@ -7,12 +7,12 @@ function(rho, phi = NULL, circle)
   ## Attention: phi corresponds to the angle
   ## between y and the direction wanted, measured clockwise.
   ## This corresponds to an angle of
-  ## pi/2-phi in Ordinary polar coordinates  
+  ## pi/2-phi in Ordinary polar coordinates
 {
   xy <- getXY(rho, phi, unidim.allowed=FALSE)
   rho <- xy$x
   phi <- xy$y
   return(data.frame(x=rho*sin(phi/circle*2*pi),
                     y=rho*cos(phi/circle*2*pi)))
-}
+} ## clock2cart
 
