@@ -1,4 +1,4 @@
-"val.rose" <-
+`val.rose` <-
 function(x)
   ## Validation function for rose-class
   ## Author: Rene Locher
@@ -9,7 +9,7 @@ function(x)
     if (length(x@circle)!=1) return(paste("length of 'circle' is ",
                 length(x@circle),", but must be 1!\n",sep=""))
     if (sum(is.na(x@cyclVar))>0)
-      return("slot 'cyclVar' must not contain NAs!\n") 
+      return("slot 'cyclVar' must not contain NAs!\n")
     if (min(x@cyclVar,rm.na=T)<0 || max(x@cyclVar,rm.na=T)>=x@circle)
       return("The following condition must be valid: 0 <= 'cyclVar' < 'circle'!\n")
     if (!any(sort(x@cyclVar)==x@cyclVar))
